Package 'psyinfr'

Title: R functions as an infrastructure for psychological research
Description: psyinfr provides R functions that serve as the infrastructure for psychological research.
Authors: Yoshihiko Kunisato
Maintainer: Yoshihiko Kunisato <[email protected]>
License: MIT + file LICENSE
Version: 0.3.2
Built: 2026-05-31 08:30:08 UTC
Source: https://github.com/ykunisato/psyinfr

Help Index


Add jpaQmd

Description

Add jpaQmd

Usage

add_jpaQmd()

Examples

# add_jpaQmd()

Add paperQmd

Description

Add paperQmd

Usage

add_paperQmd()

Examples

# add_paperQmd()

Create a JATOS .jzip file

Description

Create a JATOS .jzip file

Usage

jatosify(
  study_title,
  html_file_list,
  JATOS_version,
  study_desc = "",
  study_comment = "",
  output_dir = "."
)

Arguments

study_title

The title of the study. Used for filenames.

html_file_list

A vector of HTML filenames to be used as JATOS components (order is preserved).

JATOS_version

The version of the study (e.g., "3.9.0").

study_desc

A short description of the study (optional).

study_comment

Comments about the study (optional).

output_dir

The output directory for the .jzip file (defaults to the current directory).

Examples

# jatosify("exp01",c("ic.html","age_gender.html","task01.html"),"3.9")

render function for Japanese e-labnotebook in PDF

Description

render function for Japanese e-labnotebook in PDF

Usage

render_elnjp_pdf(Rmd_file)

Arguments

Rmd_file

file name of R Markdown file


start research with new Japanese e-labnotebook

Description

start research with new Japanese e-labnotebook

Usage

researchIn(rc = TRUE)

Arguments

rc

If you are using Research Compendium of senshuRmd, you can create a e-labnotebook file in the "labnote" directory from the current directory. In that case, please set rc to TURE.

Examples

# researchIn()

upload Japanese e-labnotebook to GitHub

Description

upload Japanese e-labnotebook to GitHub

Usage

researchOut(rc = TRUE)

Arguments

rc

If you are using Research Compendium of senshuRmd, you can create a e-labnotebook file in the "labnote" directory from the current directory. In that case, please set rc to TURE.

Examples

# researchOut()

run high load computing and psuh to GitHub

Description

run high load computing and psuh to GitHub

Usage

runHighLoad(r_file)

Arguments

r_file

set r file to run

Examples

# runHighLoad(r_file)

run r files using parallel

Description

run r files using parallel

Usage

runParallelR(r_files)

Arguments

r_files

set vector of r files


R Markdown output formats Template for thesis at Department of Psychology, Senshu University

Description

R Markdown output formats Template for thesis at Department of Psychology, Senshu University

Usage

senshu_thesis(Rmd_file, Bib_file)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file


Set template files for CBAT

Description

Set template files for CBAT

Usage

set_cbat(task_name = "task_name", jsPsych_version = "8.2.2", use_rc = 1)

Arguments

task_name

name of task

jsPsych_version

If you set a specific version number of jsPsych, set_jsPsych prepare a file with that version of jsPsych.

use_rc

Specify 1 as the argument if you want to create a folder with the project name and place the file inside it, 2 if you want to place the file in the current working directory, and 3 if a Research Compendium is set up.

Examples

# set_cbat("stroop","8.2.2")

Set template files for Phaser3

Description

Set template files for Phaser3

Usage

set_phaser(game_name = "game_name", phaser_version = "3.80.1", use_rc = TRUE)

Arguments

game_name

name of task

phaser_version

version of phaser

use_rc

If you don"t use the RC, set FALSE.

Examples

# set_phaser("game1","3.80.1",FALSE)

Research Compendium of Department of Psychology, Senshu University

Description

Research Compendium of Department of Psychology, Senshu University

Usage

set_rc()

Examples

# set_rc()

run high load computing and psuh to GitHub

Description

run high load computing and psuh to GitHub

Usage

setGitSlack(
  git_name,
  git_email,
  slack_token = "FALSE",
  slack_channel = "#general"
)

Arguments

git_name

set user name of GitHub

git_email

set e-mail of GitHub

slack_token

set slack API token

slack_channel

set channel name of slack

Examples

# setGitSlack(user_name_github, email_github, slack_token, slack_channel, slack_username)

upload Japanese e-labnotebook to OSF

Description

upload Japanese e-labnotebook to OSF

Usage

up2osf(eln_osf = TRUE, rc_osf = TRUE)

Arguments

eln_osf

URL of pdf directory in OSF

rc_osf

If you are using Research Compendium of senshuRmd, you can create a e-labnotebook file in the "labnote" directory from the current directory. In that case, please set rc to TURE.