| Title: | R functions as an infrastructure for psychological research |
|---|---|
| Description: | psyinfr provides R functions that serve as the infrastructure for psychological research. |
| Authors: | Yoshihiko Kunisato |
| Maintainer: | Yoshihiko Kunisato <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.2 |
| Built: | 2026-05-31 08:30:08 UTC |
| Source: | https://github.com/ykunisato/psyinfr |
Add jpaQmd
add_jpaQmd()add_jpaQmd()
# add_jpaQmd()# add_jpaQmd()
Add paperQmd
add_paperQmd()add_paperQmd()
# add_paperQmd()# add_paperQmd()
Create a JATOS .jzip file
jatosify( study_title, html_file_list, JATOS_version, study_desc = "", study_comment = "", output_dir = "." )jatosify( study_title, html_file_list, JATOS_version, study_desc = "", study_comment = "", output_dir = "." )
study_title |
The title of the study. Used for filenames. |
html_file_list |
A vector of HTML filenames to be used as JATOS components (order is preserved). |
JATOS_version |
The version of the study (e.g., "3.9.0"). |
study_desc |
A short description of the study (optional). |
study_comment |
Comments about the study (optional). |
output_dir |
The output directory for the .jzip file (defaults to the current directory). |
# jatosify("exp01",c("ic.html","age_gender.html","task01.html"),"3.9")# jatosify("exp01",c("ic.html","age_gender.html","task01.html"),"3.9")
render function for Japanese e-labnotebook in PDF
render_elnjp_pdf(Rmd_file)render_elnjp_pdf(Rmd_file)
Rmd_file |
file name of R Markdown file |
start research with new Japanese e-labnotebook
researchIn(rc = TRUE)researchIn(rc = TRUE)
rc |
If you are using Research Compendium of senshuRmd, you can create a e-labnotebook file in the "labnote" directory from the current directory. In that case, please set rc to TURE. |
# researchIn()# researchIn()
upload Japanese e-labnotebook to GitHub
researchOut(rc = TRUE)researchOut(rc = TRUE)
rc |
If you are using Research Compendium of senshuRmd, you can create a e-labnotebook file in the "labnote" directory from the current directory. In that case, please set rc to TURE. |
# researchOut()# researchOut()
run high load computing and psuh to GitHub
runHighLoad(r_file)runHighLoad(r_file)
r_file |
set r file to run |
# runHighLoad(r_file)# runHighLoad(r_file)
run r files using parallel
runParallelR(r_files)runParallelR(r_files)
r_files |
set vector of r files |
R Markdown output formats Template for thesis at Department of Psychology, Senshu University
senshu_thesis(Rmd_file, Bib_file)senshu_thesis(Rmd_file, Bib_file)
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
Set template files for CBAT
set_cbat(task_name = "task_name", jsPsych_version = "8.2.2", use_rc = 1)set_cbat(task_name = "task_name", jsPsych_version = "8.2.2", use_rc = 1)
task_name |
name of task |
jsPsych_version |
If you set a specific version number of jsPsych, set_jsPsych prepare a file with that version of jsPsych. |
use_rc |
Specify 1 as the argument if you want to create a folder with the project name and place the file inside it, 2 if you want to place the file in the current working directory, and 3 if a Research Compendium is set up. |
# set_cbat("stroop","8.2.2")# set_cbat("stroop","8.2.2")
Set template files for Phaser3
set_phaser(game_name = "game_name", phaser_version = "3.80.1", use_rc = TRUE)set_phaser(game_name = "game_name", phaser_version = "3.80.1", use_rc = TRUE)
game_name |
name of task |
phaser_version |
version of phaser |
use_rc |
If you don"t use the RC, set FALSE. |
# set_phaser("game1","3.80.1",FALSE)# set_phaser("game1","3.80.1",FALSE)
Research Compendium of Department of Psychology, Senshu University
set_rc()set_rc()
# set_rc()# set_rc()
run high load computing and psuh to GitHub
setGitSlack( git_name, git_email, slack_token = "FALSE", slack_channel = "#general" )setGitSlack( git_name, git_email, slack_token = "FALSE", slack_channel = "#general" )
git_name |
set user name of GitHub |
git_email |
set e-mail of GitHub |
slack_token |
set slack API token |
slack_channel |
set channel name of slack |
# setGitSlack(user_name_github, email_github, slack_token, slack_channel, slack_username)# setGitSlack(user_name_github, email_github, slack_token, slack_channel, slack_username)
upload Japanese e-labnotebook to OSF
up2osf(eln_osf = TRUE, rc_osf = TRUE)up2osf(eln_osf = TRUE, rc_osf = TRUE)
eln_osf |
URL of pdf directory in OSF |
rc_osf |
If you are using Research Compendium of senshuRmd, you can create a e-labnotebook file in the "labnote" directory from the current directory. In that case, please set rc to TURE. |